searchNodes=[{"doc":"Runs sidecar processes with Elixir appsSidecar's goal is to serve the common need for running sidecar processes alongside an Elixir application. For example, one might need to run an ngrok proxy alongside their Phoenix application in order to test incoming webhook URLs.One way of solving this problem is by using a tool like foreman, but using this tool isn't always desirable. Sidecar allows a developer to specify sidecar processes that run as part of their application's supervision tree, instead.In order to use Sidecar, first specify a set of processes to run:config :sidecar, processes: [ ngrok: &quot;ngrok http 4000&quot; ]Then, add Sidecar.Supervisor to your app's supervision tree:def start(_type, _args) do children = [ # ...etc. Sidecar.Supervisor ] endNote that sidecar processes can also be specified in the child spec:def start(_type, _args) do children = [ # ...etc. {Sidecar.Supervisor, [processes: [ngrok: &quot;ngrok http 4000&quot;]]} ] endAnd they can also be lazily evaluated each time the process starts or is restarted:def start(_type, _args) do children = [ # ...etc. {Sidecar.Supervisor, [processes: [ngrok: fn -&gt; &quot;ngrok http \#{MyApp.Endpoint.config(:http)[:port]}&quot; end]]} ] end","ref":"Sidecar.html","title":"Sidecar","type":"module"},{"doc":"Supervises a single sidecar processIt is recommended one uses Sidecar.Supervisor to run sidecar processes, rather than using this module manually.","ref":"Sidecar.Process.html","title":"Sidecar.Process","type":"module"},{"doc":"Start a supervised sidecar process.","ref":"Sidecar.Process.html#start_link/1","title":"Sidecar.Process.start_link/1","type":"function"},{"doc":"Options used to start a sidecar processname An identifier for the processcommand The command to run, which is passed to Port.open/2 using {:spawn, command}. If the command is a function, the function is evaluated just before the sidecar process is started. Its return value will be the command.","ref":"Sidecar.Process.html#t:init_opts/0","title":"Sidecar.Process.init_opts/0","type":"type"},{"doc":"Supervises a list of sidecar processes","ref":"Sidecar.Supervisor.html","title":"Sidecar.Supervisor","type":"module"},{"doc":"Start one or more supervised sidecar processes.ExamplesSidecar.Supervisor.start_link(processes: [ ngrok: &quot;ngrok http 4000&quot; ])","ref":"Sidecar.Supervisor.html#start_link/1","title":"Sidecar.Supervisor.start_link/1","type":"function"},{"doc":"Options used to start a list of sidecar processes.processes A keyword list of processes to start whose keys are unique process identifiers, and whose values are Sidecar.Process.init_opts/0 lists","ref":"Sidecar.Supervisor.html#t:init_opts/0","title":"Sidecar.Supervisor.init_opts/0","type":"type"},{"doc":"Sidecar Sidecar makes it easy to run sidecar processes alongside your main application. This is especially useful in development when you may want to spin up a process like npm run dev or an ngrok proxy.","ref":"readme.html","title":"Sidecar","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding sidecar to your list of dependencies in mix.exs:def deps do [ {:sidecar, &quot;~&gt; 0.1.0&quot;} ] end","ref":"readme.html#installation","title":"Sidecar - Installation","type":"extras"},{"doc":"First, configure your sidecar processes:config :sidecar, processes: [ ngrok: &quot;ngrok http 4000&quot;, npm: &quot;npm run dev&quot; ]Then, add the Sidecar supervisor to your application's supervision tree:def start(_type, _args) do children = [ # ...etc. Sidecar.Supervisor ] endDocumentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/sidecar.","ref":"readme.html#configuration","title":"Sidecar - Configuration","type":"extras"},{"doc":"MIT LicenseCopyright (c) 2020 Jonathan ClemPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}]